/*******************************************************************************
* File Name: ExIntClock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_ExIntClock_H)
#define CY_CLOCK_ExIntClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void ExIntClock_Start(void) ;
void ExIntClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void ExIntClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void ExIntClock_StandbyPower(uint8 state) ;
void ExIntClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 ExIntClock_GetDividerRegister(void) ;
void ExIntClock_SetModeRegister(uint8 modeBitMask) ;
void ExIntClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 ExIntClock_GetModeRegister(void) ;
void ExIntClock_SetSourceRegister(uint8 clkSource) ;
uint8 ExIntClock_GetSourceRegister(void) ;
#if defined(ExIntClock__CFG3)
void ExIntClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 ExIntClock_GetPhaseRegister(void) ;
#endif /* defined(ExIntClock__CFG3) */

#define ExIntClock_Enable()                       ExIntClock_Start()
#define ExIntClock_Disable()                      ExIntClock_Stop()
#define ExIntClock_SetDivider(clkDivider)         ExIntClock_SetDividerRegister(clkDivider, 1u)
#define ExIntClock_SetDividerValue(clkDivider)    ExIntClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define ExIntClock_SetMode(clkMode)               ExIntClock_SetModeRegister(clkMode)
#define ExIntClock_SetSource(clkSource)           ExIntClock_SetSourceRegister(clkSource)
#if defined(ExIntClock__CFG3)
#define ExIntClock_SetPhase(clkPhase)             ExIntClock_SetPhaseRegister(clkPhase)
#define ExIntClock_SetPhaseValue(clkPhase)        ExIntClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(ExIntClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define ExIntClock_CLKEN              (* (reg8 *) ExIntClock__PM_ACT_CFG)
#define ExIntClock_CLKEN_PTR          ((reg8 *) ExIntClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define ExIntClock_CLKSTBY            (* (reg8 *) ExIntClock__PM_STBY_CFG)
#define ExIntClock_CLKSTBY_PTR        ((reg8 *) ExIntClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define ExIntClock_DIV_LSB            (* (reg8 *) ExIntClock__CFG0)
#define ExIntClock_DIV_LSB_PTR        ((reg8 *) ExIntClock__CFG0)
#define ExIntClock_DIV_PTR            ((reg16 *) ExIntClock__CFG0)

/* Clock MSB divider configuration register. */
#define ExIntClock_DIV_MSB            (* (reg8 *) ExIntClock__CFG1)
#define ExIntClock_DIV_MSB_PTR        ((reg8 *) ExIntClock__CFG1)

/* Mode and source configuration register */
#define ExIntClock_MOD_SRC            (* (reg8 *) ExIntClock__CFG2)
#define ExIntClock_MOD_SRC_PTR        ((reg8 *) ExIntClock__CFG2)

#if defined(ExIntClock__CFG3)
/* Analog clock phase configuration register */
#define ExIntClock_PHASE              (* (reg8 *) ExIntClock__CFG3)
#define ExIntClock_PHASE_PTR          ((reg8 *) ExIntClock__CFG3)
#endif /* defined(ExIntClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define ExIntClock_CLKEN_MASK         ExIntClock__PM_ACT_MSK
#define ExIntClock_CLKSTBY_MASK       ExIntClock__PM_STBY_MSK

/* CFG2 field masks */
#define ExIntClock_SRC_SEL_MSK        ExIntClock__CFG2_SRC_SEL_MASK
#define ExIntClock_MODE_MASK          (~(ExIntClock_SRC_SEL_MSK))

#if defined(ExIntClock__CFG3)
/* CFG3 phase mask */
#define ExIntClock_PHASE_MASK         ExIntClock__CFG3_PHASE_DLY_MASK
#endif /* defined(ExIntClock__CFG3) */

#endif /* CY_CLOCK_ExIntClock_H */


/* [] END OF FILE */
