/*******************************************************************************
* File Name: INTR.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_INTR_H) /* Pins INTR_H */
#define CY_PINS_INTR_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "INTR_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 INTR__PORT == 15 && ((INTR__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    INTR_Write(uint8 value);
void    INTR_SetDriveMode(uint8 mode);
uint8   INTR_ReadDataReg(void);
uint8   INTR_Read(void);
void    INTR_SetInterruptMode(uint16 position, uint16 mode);
uint8   INTR_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the INTR_SetDriveMode() function.
     *  @{
     */
        #define INTR_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define INTR_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define INTR_DM_RES_UP          PIN_DM_RES_UP
        #define INTR_DM_RES_DWN         PIN_DM_RES_DWN
        #define INTR_DM_OD_LO           PIN_DM_OD_LO
        #define INTR_DM_OD_HI           PIN_DM_OD_HI
        #define INTR_DM_STRONG          PIN_DM_STRONG
        #define INTR_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define INTR_MASK               INTR__MASK
#define INTR_SHIFT              INTR__SHIFT
#define INTR_WIDTH              1u

/* Interrupt constants */
#if defined(INTR__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in INTR_SetInterruptMode() function.
     *  @{
     */
        #define INTR_INTR_NONE      (uint16)(0x0000u)
        #define INTR_INTR_RISING    (uint16)(0x0001u)
        #define INTR_INTR_FALLING   (uint16)(0x0002u)
        #define INTR_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define INTR_INTR_MASK      (0x01u) 
#endif /* (INTR__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define INTR_PS                     (* (reg8 *) INTR__PS)
/* Data Register */
#define INTR_DR                     (* (reg8 *) INTR__DR)
/* Port Number */
#define INTR_PRT_NUM                (* (reg8 *) INTR__PRT) 
/* Connect to Analog Globals */                                                  
#define INTR_AG                     (* (reg8 *) INTR__AG)                       
/* Analog MUX bux enable */
#define INTR_AMUX                   (* (reg8 *) INTR__AMUX) 
/* Bidirectional Enable */                                                        
#define INTR_BIE                    (* (reg8 *) INTR__BIE)
/* Bit-mask for Aliased Register Access */
#define INTR_BIT_MASK               (* (reg8 *) INTR__BIT_MASK)
/* Bypass Enable */
#define INTR_BYP                    (* (reg8 *) INTR__BYP)
/* Port wide control signals */                                                   
#define INTR_CTL                    (* (reg8 *) INTR__CTL)
/* Drive Modes */
#define INTR_DM0                    (* (reg8 *) INTR__DM0) 
#define INTR_DM1                    (* (reg8 *) INTR__DM1)
#define INTR_DM2                    (* (reg8 *) INTR__DM2) 
/* Input Buffer Disable Override */
#define INTR_INP_DIS                (* (reg8 *) INTR__INP_DIS)
/* LCD Common or Segment Drive */
#define INTR_LCD_COM_SEG            (* (reg8 *) INTR__LCD_COM_SEG)
/* Enable Segment LCD */
#define INTR_LCD_EN                 (* (reg8 *) INTR__LCD_EN)
/* Slew Rate Control */
#define INTR_SLW                    (* (reg8 *) INTR__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define INTR_PRTDSI__CAPS_SEL       (* (reg8 *) INTR__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define INTR_PRTDSI__DBL_SYNC_IN    (* (reg8 *) INTR__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define INTR_PRTDSI__OE_SEL0        (* (reg8 *) INTR__PRTDSI__OE_SEL0) 
#define INTR_PRTDSI__OE_SEL1        (* (reg8 *) INTR__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define INTR_PRTDSI__OUT_SEL0       (* (reg8 *) INTR__PRTDSI__OUT_SEL0) 
#define INTR_PRTDSI__OUT_SEL1       (* (reg8 *) INTR__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define INTR_PRTDSI__SYNC_OUT       (* (reg8 *) INTR__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(INTR__SIO_CFG)
    #define INTR_SIO_HYST_EN        (* (reg8 *) INTR__SIO_HYST_EN)
    #define INTR_SIO_REG_HIFREQ     (* (reg8 *) INTR__SIO_REG_HIFREQ)
    #define INTR_SIO_CFG            (* (reg8 *) INTR__SIO_CFG)
    #define INTR_SIO_DIFF           (* (reg8 *) INTR__SIO_DIFF)
#endif /* (INTR__SIO_CFG) */

/* Interrupt Registers */
#if defined(INTR__INTSTAT)
    #define INTR_INTSTAT            (* (reg8 *) INTR__INTSTAT)
    #define INTR_SNAP               (* (reg8 *) INTR__SNAP)
    
	#define INTR_0_INTTYPE_REG 		(* (reg8 *) INTR__0__INTTYPE)
#endif /* (INTR__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_INTR_H */


/* [] END OF FILE */
